# Android Sms Retriever 
[![Fork](https://img.shields.io/github/forks/arsamme/flutter-sms-retriever?style=social)](https://github.com/arsamme/flutter-sms-retriever/fork)&nbsp; [![Star](https://img.shields.io/github/stars/arsamme/flutter-sms-retriever?style=social)](https://github.com/arsamme/flutter-sms-retriever)&nbsp; [![Watches](https://img.shields.io/github/watchers/arsamme/flutter-sms-retriever?style=social)](https://github.com/arsamme/flutter-sms-retriever/)&nbsp; [![pub package](https://img.shields.io/pub/v/android_sms_retriever.svg)](https://pub.dartlang.org/packages/android_sms_retriever)&nbsp; [![Example](https://img.shields.io/badge/Example-Ex-success)](https://pub.dev/packages/android_sms_retriever/example)

Flutter plugin for retrieving OTP code sent in sms automatically and without getting SMS permission in Android. This package has support for Smart Lock credentials, you can use for storing user's phone number and retrieving whenever you want. Read more [here](https://developers.google.com/identity/sms-retriever/)

## Getting Started

Install
```yaml
dependencies:
  android_sms_retriever: ^1.0.0
```

Import
```dart
import 'package:android_sms_retriever/android_sms_retriever.dart';
```

### App signature
To retrieve a app signature. App signature should be placed at end of SMS so SmsRetriever API can verify SMS is sent from your server.
```dart
String appSignature = await SmsRetriever.getAppSignature();
```

### Request phone number
You can request android to open a dialog with user's phone numbers, then user can select one.
```dart
String phoneNumber = await ArsSmsRetriever.requestPhoneNumber();
```

### Store phone number
You can store user's phone number to use later, For example: When user uninstalls application and installs again.
You should pass your application's website URL and phone number to this function.
```dart
await ArsSmsRetriever.storePhoneNumber('https://arsam.me','09027777254');
```

### Retrieve stored phone number
To retrieve stored phone number use this function.
You should pass your application's website URL to this function.
```dart
String phoneNumber = await ArsSmsRetriever.retrieveStoredPhoneNumber('https://arsam.me');
```

### Delete stored phone number
To delete stored phone number use this function.
You should pass your application's website URL and phone number to this function.
```dart
await ArsSmsRetriever.deleteStoredPhoneNumber('https://arsam.me','09027777254');
```

### Start listening for SMS
To start listening for an incoming SMS
```dart
String smsCode = await ArsSmsRetriever.startSmsListener();
```

### Close receiver after getting SMS
Stop listening after getting the SMS
```dart
ArsSmsRetriever.stopSmsListener();
```

### Request one time SMS consent
Using this function, when sms received android will ask user to let application use message and extract code, even if sms message does not contain application signature.
You can pass sender phone number in order to detect messages sent from specific sender.
```dart
String smsCode = await ArsSmsRetriever.requestOneTimeConsentSms('+9850003001');
```

#### Note
SMS format should be like this :

```text
Your example code is: 123456

appSignature
```